@@ -1,6 +1,9 @@
+from datetime import datetime
+
 from piperider_cli.assertion_engine import AssertionContext, AssertionResult
 from piperider_cli.assertion_engine.assertion import ValidationResult
 from piperider_cli.assertion_engine.types.base import BaseAssertionType
+from piperider_cli.assertion_engine.types.assert_metrics import AssertMetric
 
 
 class AssertColumnNotNull(BaseAssertionType):
@@ -47,6 +50,86 @@ class AssertColumnExist(BaseAssertionType):
         return ValidationResult(context).keep_no_args()
 
 
+class AssertColumnValue(BaseAssertionType):
+    def name(self):
+        return "assert_column_value"
+
+    def execute(self, context: AssertionContext, table: str, column: str, metrics: dict):
+        target_metrics = metrics.get('tables', {}).get(table)
+        if column:
+            target_metrics = target_metrics.get('columns', {}).get(column)
+
+        if not target_metrics:
+            return context.result.fail_with_metric_not_found_error(context.table, context.column)
+
+        context.result.expected = AssertMetric.to_interval_notation(context.asserts)
+        has_fail = False
+
+        if target_metrics.get('min') is not None:
+            if not AssertMetric.assert_metric_boundary(target_metrics.get('min'), context.asserts):
+                has_fail = True
+        else:
+            return context.result.fail()
+
+        if target_metrics.get('max') is not None:
+            if not AssertMetric.assert_metric_boundary(target_metrics.get('max'), context.asserts):
+                has_fail = True
+        else:
+            return context.result.fail()
+
+        context.result.actual = AssertMetric.to_interval_notation({
+            'gte': target_metrics.get('min'),
+            'lte': target_metrics.get('max')
+        })
+
+        if has_fail:
+            return context.result.fail()
+        return context.result.success()
+
+    def validate(self, context: AssertionContext) -> ValidationResult:
+        results = ValidationResult(context)
+
+        names = ['gte', 'lte', 'gt', 'lt']
+        results = results.allow_only(*names) \
+            .require_metric_consistency(*names)
+
+        if context.asserts is None:
+            results.errors.append(f'At least one of {names} is needed.')
+
+        if results.errors:
+            return results
+
+        self._assert_value_validation(context.asserts, results)
+
+        return results
+
+    @staticmethod
+    def _assert_value_validation(value_boundary: dict, results: ValidationResult):
+        if len(value_boundary.keys()) == 1:
+            pass
+        elif len(value_boundary.keys()) == 2:
+            lower = None
+            upper = None
+            for op, v in value_boundary.items():
+                if op.startswith('lt'):
+                    upper = v
+                elif op.startswith('gt'):
+                    lower = v
+
+            if upper is None or lower is None:
+                results.errors.append('Please specified your metric upper and lower boundary')
+                return
+
+            if isinstance(upper, str) and isinstance(lower, str):
+                upper = datetime.fromisoformat(upper)
+                lower = datetime.fromisoformat(lower)
+            if upper < lower:
+                results.errors.append("The 'lt' or 'lte' value should be greater than or equal to "
+                                      "the 'gt' or 'gte' value.")
+        else:
+            results.errors.append('The number of operator should be 1 or 2.')
+
+
 def assert_column_not_null(context: AssertionContext, table: str, column: str, metrics: dict) -> AssertionResult:
     column_metrics = metrics.get('tables', {}).get(table, {}).get('columns', {}).get(column)
     if not column_metrics:
@@ -59,7 +142,7 @@ def assert_column_not_null(context: AssertionContext, table: str, column: str, m
     non_nulls = column_metrics.get('non_nulls')
 
     success = (samples == non_nulls)
-    context.result.actual = dict(success=success)
+    context.result.actual = None
 
     if success:
         return context.result.success()
@@ -100,7 +183,7 @@ def assert_column_unique(context: AssertionContext, table: str, column: str, met
     distinct = column_metrics.get('distinct')
 
     success = (valids == distinct)
-    context.result.actual = dict(success=success)
+    context.result.actual = None
 
     if success:
         return context.result.success()
