@@ -227,11 +227,13 @@ class Profiler:
                     row_count, = conn.execute(stmt).fetchone()
 
         result['row_count'] = result['samples'] = row_count
+        result['samples_p'] = 1
 
         if self.config:
             limit = self.config.profiler_config.get('table', {}).get('limit', 0)
             if row_count > limit > 0:
                 result['samples'] = limit
+                result['samples_p'] = limit / row_count if row_count else None
 
         if created:
             result['created'] = created
@@ -292,7 +294,10 @@ class Profiler:
             "name": table.name,
             "row_count": 0,
             "samples": 0,
+            "samples_p": None,
             "col_count": col_count,
+            "duplicate_rows": None,
+            "duplicate_rows_p": None,
             "columns": columns
         }
 
@@ -305,6 +310,8 @@ class Profiler:
         # Profile table metrics
         self._profile_table_metadata(result, table)
         self._profile_table_duplicate_rows(result, table)
+        result['duplicate_rows_p'] = result['duplicate_rows'] / result['samples'] \
+            if result['duplicate_rows'] is not None and result['samples'] else None
         self.event_handler.handle_table_progress(result, col_count, col_index)
 
         # Profile columns
@@ -312,11 +319,15 @@ class Profiler:
             for column in candidate_columns:
                 columns[column.name] = self._profile_column(table, column)
                 columns[column.name]['total'] = result['row_count']
+                columns[column.name]['samples_p'] = columns[column.name]['samples'] / columns[column.name]['total'] \
+                    if columns[column.name]['total'] else None
                 col_index = col_index + 1
                 self.event_handler.handle_table_progress(result, col_count, col_index)
 
             self.event_handler.handle_table_end(result)
         else:
+            for column in candidate_columns:
+                columns[column.name] = None
             with concurrent.futures.ThreadPoolExecutor(max_workers=5) as executor:
                 future_to_profile = {executor.submit(self._profile_column, table, column): column for column in
                                      candidate_columns}
@@ -330,6 +341,8 @@ class Profiler:
                         else:
                             columns[column.name] = data
                             columns[column.name]['total'] = result['row_count']
+                            columns[column.name]['samples_p'] = columns[column.name]['samples'] / columns[column.name]['total'] \
+                                if columns[column.name]['total'] else None
                             col_index = col_index + 1
                             self.event_handler.handle_table_progress(result, col_count, col_index)
                 finally:
@@ -475,10 +488,14 @@ class BaseColumnProfiler:
             return {
                 'total': None,
                 'samples': _total,
+                'samples_p': None,
                 'non_nulls': _non_nulls,
+                'non_nulls_p': _non_nulls / _total if _total else None,
                 'nulls': _total - _non_nulls,
+                'nulls_p': (_total - _non_nulls) / _total if _total else None,
                 'valids': _non_nulls,
                 'invalids': 0,
+                'invalids_p': 0,
                 'distribution': None,
             }
 
@@ -556,27 +573,45 @@ class StringColumnProfiler(BaseColumnProfiler):
             result = {
                 'total': None,
                 'samples': _total,
+                'samples_p': None,
                 'non_nulls': _non_nulls,
+                'non_nulls_p': _non_nulls / _total if _total else None,
                 'nulls': _total - _non_nulls,
+                'nulls_p': None,
                 'valids': _valids,
+                'valids_p': _valids / _total if _total else None,
                 'invalids': _non_nulls - _valids,
+                'invalids_p': None,
                 'zero_length': _zero_length,
+                'zero_length_p': _zero_length / _total if _total else None,
                 'non_zero_length': _valids - _zero_length,
+                'non_zero_length_p': None,
 
                 'distinct': _distinct,
+                'distinct_p': _distinct / _non_nulls if _non_nulls else None,
                 'min': _min,
+                'min_length': _min,
                 'max': _max,
+                'max_length': _max,
                 'sum': _sum,
                 'avg': _avg,
+                'avg_length': _avg,
                 'stddev': _stddev,
+                'stddev_length': _stddev,
             }
+            result['nulls_p'] = 1 - result['non_nulls_p'] if result['non_nulls_p'] is not None else None
+            result['invalids_p'] = 1 - result['valids_p'] if result['valids_p'] is not None else None
+            result['non_zero_length_p'] = 1 - result['zero_length_p'] if result['zero_length_p'] is not None else None
 
             # uniqueness
             _non_duplicates = profile_non_duplicate(conn, cte, cte.c.c)
             result.update({
                 "duplicates": _valids - _non_duplicates,
+                "duplicates_p": None,
                 "non_duplicates": _non_duplicates,
+                "non_duplicates_p": _non_duplicates / _non_nulls if _non_nulls else None,
             })
+            result['duplicates_p'] = 1 - result['non_duplicates_p'] if result['non_duplicates_p'] is not None else None
 
             # top k
             topk = None
@@ -589,6 +624,7 @@ class StringColumnProfiler(BaseColumnProfiler):
             if _valids > 0:
                 histogram = profile_histogram(conn, cte, cte.c.len, _min, _max, True)
             result['histogram'] = histogram
+            result['histogram_length'] = histogram
 
             # deprecated
             result['distribution'] = {
@@ -673,28 +709,44 @@ class NumericColumnProfiler(BaseColumnProfiler):
             result = {
                 'total': None,
                 'samples': _total,
+                'samples_p': None,
                 'non_nulls': _non_nulls,
+                'non_nulls_p': _non_nulls / _total if _total else None,
                 'nulls': _total - _non_nulls,
+                'nulls_p': None,
                 'valids': _valids,
+                'valids_p': _valids / _total if _total else None,
                 'invalids': _non_nulls - _valids,
+                'invalids_p': None,
                 'zeros': _zeros,
+                'zeros_p': _zeros / _total if _total else None,
                 'negatives': _negatives,
+                'negatives_p': _negatives / _total if _total else None,
                 'positives': _valids - _zeros - _negatives,
+                'positives_p': None,
 
                 'distinct': _distinct,
+                'distinct_p': _distinct / _non_nulls if _non_nulls else None,
                 'min': _min,
                 'max': _max,
                 'sum': _sum,
                 'avg': _avg,
                 'stddev': _stddev,
             }
+            result['nulls_p'] = 1 - result['non_nulls_p'] if result['non_nulls_p'] is not None else None
+            result['invalids_p'] = 1 - result['valids_p'] if result['valids_p'] is not None else None
+            result['positives_p'] = 1 - result['zeros_p'] - result['negatives_p'] \
+                if result['zeros_p'] is not None and result['negatives_p'] is not None else None
 
             # uniqueness
             _non_duplicates = profile_non_duplicate(conn, cte, cte.c.c)
             result.update({
                 "duplicates": _valids - _non_duplicates,
+                "duplicates_p": None,
                 "non_duplicates": _non_duplicates,
+                "non_duplicates_p": _non_duplicates / _non_nulls if _non_nulls else None
             })
+            result['duplicates_p'] = 1 - result['non_duplicates_p'] if result['non_duplicates_p'] is not None else None
 
             # histogram
             histogram = None
@@ -1003,21 +1055,32 @@ class DatetimeColumnProfiler(BaseColumnProfiler):
             result = {
                 'total': None,
                 'samples': _total,
+                'samples_p': None,
                 'non_nulls': _non_nulls,
+                'non_nulls_p': _non_nulls / _total if _total else None,
                 'nulls': _total - _non_nulls,
+                'nulls_p': None,
                 'valids': _valids,
+                'valids_p': _valids / _total if _total else None,
                 'invalids': _non_nulls - _valids,
+                'invalids_p': None,
                 'distinct': _distinct,
+                'distinct_p': _distinct / _non_nulls if _non_nulls else None,
                 'min': _min.isoformat() if _min is not None else None,
                 'max': _max.isoformat() if _max is not None else None,
             }
+            result['nulls_p'] = 1 - result['non_nulls_p'] if result['non_nulls_p'] is not None else None
+            result['invalids_p'] = 1 - result['valids_p'] if result['valids_p'] is not None else None
 
             # uniqueness
             _non_duplicates = profile_non_duplicate(conn, cte, cte.c.c)
             result.update({
                 "duplicates": _valids - _non_duplicates,
+                "duplicates_p": None,
                 "non_duplicates": _non_duplicates,
+                "non_duplicates_p": _non_duplicates / _non_nulls if _non_nulls else None,
             })
+            result['duplicates_p'] = 1 - result['non_duplicates_p'] if result['non_duplicates_p'] is not None else None
 
             # histogram
             histogram = None
@@ -1190,16 +1253,24 @@ class BooleanColumnProfiler(BaseColumnProfiler):
             _total, _non_nulls, _valids, _trues, _distinct = result
             _falses = _valids - _trues
 
-            return {
+            result = {
                 'total': None,
                 'samples': _total,
+                'samples_p': None,
                 'non_nulls': _non_nulls,
+                'non_nulls_p': _non_nulls / _total if _total else None,
                 'nulls': _total - _non_nulls,
+                'nulls_p': None,
                 'valids': _valids,
+                'valids_p': _valids / _total if _total else None,
                 'invalids': _non_nulls - _valids,
+                'invalids_p': None,
                 'trues': _trues,
+                'trues_p': _trues / _total if _total else None,
                 'falses': _falses,
+                'falses_p': None,
                 'distinct': _distinct,
+                'distinct_p': _distinct / _non_nulls if _non_nulls else None,
 
                 # deprecated
                 'distribution': {
@@ -1209,6 +1280,12 @@ class BooleanColumnProfiler(BaseColumnProfiler):
                 }
             }
 
+            result['nulls_p'] = 1 - result['non_nulls_p'] if result['non_nulls_p'] is not None else None
+            result['invalids_p'] = 1 - result['valids_p'] if result['valids_p'] is not None else None
+            result['falses_p'] = 1 - result['trues_p'] if result['trues_p'] is not None else None
+
+            return result
+
 
 def profile_topk(conn, expr, k=20) -> dict:
     stmt = select([
